@@ -19,27 +19,30 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef EVENTS_H_
 #define EVENTS_H_
 
+/* To know about __NR_socketcall */
+#include <asm/unistd.h>
+
 /*
  * Various crap that a callback might need
  */
 struct event_filler_arguments {
-	char *buffer;	/* the buffer that will be filled with the data */
-	uint32_t buffer_size;	/* the space in the ring buffer available for this event */
-	uint32_t syscall_id;	/* the system call ID */
+	char *buffer; /* the buffer that will be filled with the data */
+	u32 buffer_size; /* the space in the ring buffer available for this event */
+	u32 syscall_id; /* the system call ID */
 #ifdef PPM_ENABLE_SENTINEL
-	uint32_t sentinel;
+	u32 sentinel;
 #endif
-	uint32_t nevents;
-	uint32_t curarg;
-	uint32_t nargs;
-	uint32_t arg_data_offset;
-	uint32_t arg_data_size;
+	u32 nevents;
+	u32 curarg;
+	u32 nargs;
+	u32 arg_data_offset;
+	u32 arg_data_size;
 	enum ppm_event_type event_type;	/* the event type */
 	struct pt_regs *regs; /* the registers containing the call arguments */
 	struct task_struct *sched_prev; /* for context switch events, the task that is being schduled out */
 	struct task_struct *sched_next; /* for context switch events, the task that is being schduled in */
 	char *str_storage; /* String storage. Size is one page. */
-#ifndef __x86_64__
+#ifdef __NR_socketcall
 	unsigned long socketcall_args[6];
 #endif
 };
@@ -58,7 +61,7 @@ struct event_filler_arguments {
 #define PPM_FAILURE_INVALID_USER_MEMORY -2
 #define PPM_FAILURE_BUG -3
 
-typedef int32_t (*filler_callback) (struct event_filler_arguments *args);
+typedef int (*filler_callback) (struct event_filler_arguments *args);
 
 struct ppm_autofill_arg {
 #define AF_ID_RETVAL -1
@@ -74,7 +77,7 @@ enum autofill_paramtype {
 
 struct ppm_event_entry {
 	filler_callback filler_callback;
-	uint16_t n_autofill_args;
+	u16 n_autofill_args;
 	enum autofill_paramtype paramtype;
 	struct ppm_autofill_arg autofill_args[PPM_MAX_AUTOFILL_ARGS];
 };
@@ -92,18 +95,18 @@ extern const struct ppm_event_entry g_ppm_events[];
  * Functions
  */
 int32_t f_sys_autofill(struct event_filler_arguments *args, const struct ppm_event_entry *evinfo);
-int32_t val_to_ring(struct event_filler_arguments *args, uint64_t val, uint16_t val_len, bool fromuser);
+int32_t val_to_ring(struct event_filler_arguments *args, uint64_t val, u16 val_len, bool fromuser, uint8_t dyn_idx);
 char *npm_getcwd(char *buf, unsigned long bufsize);
-uint16_t pack_addr(struct sockaddr *usrsockaddr, int ulen, char *targetbuf, uint16_t targetbufsize);
-uint16_t fd_to_socktuple(int fd, struct sockaddr *usrsockaddr, int ulen, bool use_userdata, bool is_inbound, char *targetbuf, uint16_t targetbufsize);
+u16 pack_addr(struct sockaddr *usrsockaddr, int ulen, char *targetbuf, u16 targetbufsize);
+u16 fd_to_socktuple(int fd, struct sockaddr *usrsockaddr, int ulen, bool use_userdata, bool is_inbound, char *targetbuf, u16 targetbufsize);
 int addr_to_kernel(void __user *uaddr, int ulen, struct sockaddr *kaddr);
 int32_t parse_readv_writev_bufs(struct event_filler_arguments *args, const struct iovec __user *iovsrc, unsigned long iovcnt, int64_t retval, int flags);
 
-static inline int32_t add_sentinel(struct event_filler_arguments *args)
+static inline int add_sentinel(struct event_filler_arguments *args)
 {
 #ifdef PPM_ENABLE_SENTINEL
-	if (likely(args->arg_data_size >= sizeof(uint32_t))) {
-		*(uint32_t *)(args->buffer + args->arg_data_offset) = args->sentinel;
+	if (likely(args->arg_data_size >= sizeof(u32))) {
+		*(u32 *)(args->buffer + args->arg_data_offset) = args->sentinel;
 		args->arg_data_offset += 4;
 		args->arg_data_size -= 4;
 		return PPM_SUCCESS;
