@@ -493,6 +493,21 @@ int lua_cbacks::run_sysdig(lua_State *ls)
 	return 0;
 }
 
+int lua_cbacks::end_capture(lua_State *ls) 
+{
+	lua_getglobal(ls, "sichisel");
+
+	sinsp_chisel* ch = (sinsp_chisel*)lua_touserdata(ls, -1);
+	lua_pop(ls, 1);
+
+	ASSERT(ch);
+	ASSERT(ch->m_lua_cinfo);
+
+	ch->m_lua_cinfo->m_end_capture = true;
+
+	return 0;
+}
+
 int lua_cbacks::is_live(lua_State *ls) 
 {
 	lua_getglobal(ls, "sichisel");
@@ -577,7 +592,14 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 	threadinfo_map_iterator_t it;
 	unordered_map<int64_t, sinsp_fdinfo_t>::iterator fdit;
 	uint32_t j;
+	sinsp_filter* filter = NULL;
+	sinsp_evt tevt;
+	scap_evt tscapevt;
+	char ipbuf[128];
 
+	//
+	// Get the chisel state
+	//
 	lua_getglobal(ls, "sichisel");
 
 	sinsp_chisel* ch = (sinsp_chisel*)lua_touserdata(ls, -1);
@@ -587,6 +609,37 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 	ASSERT(ch->m_lua_cinfo);
 	ASSERT(ch->m_inspector);
 
+	//
+	// If the caller specified a filter, compile it
+	//
+	if(lua_isstring(ls, 1)) 
+	{
+		string filterstr = lua_tostring(ls, 1);
+		lua_pop(ls, 1);
+
+		try
+		{
+			filter = new sinsp_filter(ch->m_inspector, filterstr, true);
+		}
+		catch(sinsp_exception& e)
+		{
+			string err = "invalid filter argument for get_thread_table in chisel " + ch->m_filename + ": " + e.what();
+			fprintf(stderr, "%s\n", err.c_str());
+			throw sinsp_exception("chisel error");
+		}
+
+		tscapevt.ts = 0;
+		tscapevt.type = PPME_SYSCALL_READ_X;
+		tscapevt.len = 0;
+
+		tevt.m_inspector = ch->m_inspector;
+		tevt.m_info = &(g_infotables.m_event_info[PPME_SYSCALL_READ_X]);
+		tevt.m_pevt = NULL;
+		tevt.m_cpuid = 0;
+		tevt.m_evtnum = 0;
+		tevt.m_pevt = &tscapevt;
+	}
+
 	threadinfo_map_t* threadtable  = ch->m_inspector->m_thread_manager->get_threads();
 
 	ASSERT(threadtable != NULL);
@@ -595,6 +648,39 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 
 	for(it = threadtable->begin(); it != threadtable->end(); ++it)
 	{
+		//
+		// Check if there's at least an fd that matches the filter.
+		// If not, skip this thread
+		//
+		sinsp_fdtable* fdtable = it->second.get_fd_table();
+
+		if(filter != NULL)
+		{
+			bool match = false;
+
+			for(fdit = fdtable->m_table.begin(); fdit != fdtable->m_table.end(); ++fdit)
+			{
+				tevt.m_tinfo = &(it->second);
+				tevt.m_fdinfo = &(fdit->second);
+				tscapevt.tid = it->first;
+				int64_t tlefd = tevt.m_tinfo->m_lastevent_fd;
+				tevt.m_tinfo->m_lastevent_fd = fdit->first;
+
+				if(filter->run(&tevt))
+				{
+					match = true;
+					break;
+				}
+
+				tevt.m_tinfo->m_lastevent_fd = tlefd;
+			}
+
+			if(!match)
+			{
+				continue;
+			}
+		}
+
 		//
 		// Set the thread properties
 		//
@@ -702,10 +788,25 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 		// Create and populate the FD table
 		//
 		lua_pushstring(ls, "fdtable");
-		sinsp_fdtable* fdtable = it->second.get_fd_table();
 		lua_newtable(ls);
 		for(fdit = fdtable->m_table.begin(); fdit != fdtable->m_table.end(); ++fdit)
 		{
+			tevt.m_tinfo = &(it->second);
+			tevt.m_fdinfo = &(fdit->second);
+			tscapevt.tid = it->first;
+			int64_t tlefd = tevt.m_tinfo->m_lastevent_fd;
+			tevt.m_tinfo->m_lastevent_fd = fdit->first;
+
+			if(filter != NULL)
+			{
+				if(filter->run(&tevt) == false)
+				{
+					continue;
+				}
+			}
+
+			tevt.m_tinfo->m_lastevent_fd = tlefd;
+
 			lua_newtable(ls);
 			lua_pushliteral(ls, "name");
 			lua_pushstring(ls, fdit->second.tostring_clean().c_str());
@@ -714,6 +815,115 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 			lua_pushstring(ls, fdit->second.get_typestring());
 			lua_settable(ls, -3);
 
+			scap_fd_type evt_type = fdit->second.m_type;
+			if(evt_type == SCAP_FD_IPV4_SOCK || evt_type == SCAP_FD_IPV4_SERVSOCK)
+			{
+				uint8_t* pip4;
+
+				if(evt_type == SCAP_FD_IPV4_SOCK)
+				{
+					// cip
+					pip4 = (uint8_t*)&(fdit->second.m_sockinfo.m_ipv4info.m_fields.m_sip);
+					snprintf(ipbuf,
+						sizeof(ipbuf),
+						"%" PRIu8 ".%" PRIu8 ".%" PRIu8 ".%" PRIu8,
+						pip4[0],
+						pip4[1],
+						pip4[2],
+						pip4[3]);
+
+					lua_pushliteral(ls, "cip");
+					lua_pushstring(ls, ipbuf);
+					lua_settable(ls, -3);
+
+					// sip
+					pip4 = (uint8_t*)&(fdit->second.m_sockinfo.m_ipv4info.m_fields.m_dip);
+					snprintf(ipbuf,
+						sizeof(ipbuf),
+						"%" PRIu8 ".%" PRIu8 ".%" PRIu8 ".%" PRIu8,
+						pip4[0],
+						pip4[1],
+						pip4[2],
+						pip4[3]);
+
+					lua_pushliteral(ls, "sip");
+					lua_pushstring(ls, ipbuf);
+					lua_settable(ls, -3);
+
+					// cport
+					lua_pushliteral(ls, "cport");
+					lua_pushnumber(ls, fdit->second.m_sockinfo.m_ipv4info.m_fields.m_sport);
+					lua_settable(ls, -3);
+
+					// sport
+					lua_pushliteral(ls, "sport");
+					lua_pushnumber(ls, fdit->second.m_sockinfo.m_ipv4info.m_fields.m_dport);
+					lua_settable(ls, -3);
+
+					// is_server
+					lua_pushliteral(ls, "is_server");
+					lua_pushboolean(ls, fdit->second.is_role_server());
+					lua_settable(ls, -3);
+				}
+				else
+				{
+					// sip
+					pip4 = (uint8_t*)&(fdit->second.m_sockinfo.m_ipv4serverinfo.m_ip);
+					snprintf(ipbuf,
+						sizeof(ipbuf),
+						"%" PRIu8 ".%" PRIu8 ".%" PRIu8 ".%" PRIu8,
+						pip4[0],
+						pip4[1],
+						pip4[2],
+						pip4[3]);
+
+					lua_pushliteral(ls, "sip");
+					lua_pushstring(ls, ipbuf);
+					lua_settable(ls, -3);
+
+					// sport
+					lua_pushliteral(ls, "sport");
+					lua_pushnumber(ls, fdit->second.m_sockinfo.m_ipv4serverinfo.m_port);
+					lua_settable(ls, -3);
+
+					// is_server
+					lua_pushliteral(ls, "is_server");
+					lua_pushboolean(ls, 1);
+					lua_settable(ls, -3);
+				}
+
+				// l4proto
+				const char* l4ps;
+				scap_l4_proto l4p = fdit->second.get_l4proto();
+
+				switch(l4p)
+				{
+				case SCAP_L4_TCP:
+					l4ps = "tcp";
+					break;
+				case SCAP_L4_UDP:
+					l4ps = "udp";
+					break;
+				case SCAP_L4_ICMP:
+					l4ps = "icmp";
+					break;
+				case SCAP_L4_RAW:
+					l4ps = "raw";
+					break;
+				default:
+					l4ps = "<NA>";
+					break;
+				}
+
+				// l4proto
+				lua_pushliteral(ls, "l4proto");
+				lua_pushstring(ls, l4ps);
+				lua_settable(ls, -3);
+			}
+
+			// is_server
+			string l4proto;
+
 			lua_rawseti(ls,-2, (uint32_t)fdit->first);
 		}
 		lua_settable(ls,-3);
@@ -724,6 +934,11 @@ int lua_cbacks::get_thread_table(lua_State *ls)
 		lua_rawseti(ls,-2, (uint32_t)it->first);
 	}
 
+	if(filter)
+	{
+		delete filter;
+	}
+
 	return 1;
 }
 
