@@ -350,25 +350,28 @@ public:
 		TYPE_LATENCY = 10,
 		TYPE_LATENCY_S = 11,
 		TYPE_LATENCY_NS = 12,
-		TYPE_DIR = 13,
-		TYPE_TYPE = 14,
-		TYPE_CPU = 15,
-		TYPE_ARGS = 16,
-		TYPE_ARGSTR = 17,
-		TYPE_ARGRAW = 18,
-		TYPE_INFO = 19,
-		TYPE_BUFFER = 20,
-		TYPE_RESSTR = 21,
-		TYPE_RESRAW = 22,
-		TYPE_FAILED = 23,
-		TYPE_ISIO = 24,
-		TYPE_ISIO_READ = 25,
-		TYPE_ISIO_WRITE = 26,
-		TYPE_IODIR = 27,
-		TYPE_ISWAIT = 28,
-		TYPE_ISSYSLOG = 29,
-		TYPE_COUNT = 30,
-		TYPE_AROUND = 31,
+		TYPE_DELTA = 13,
+		TYPE_DELTA_S = 14,
+		TYPE_DELTA_NS = 15,
+		TYPE_DIR = 16,
+		TYPE_TYPE = 17,
+		TYPE_CPU = 18,
+		TYPE_ARGS = 19,
+		TYPE_ARGSTR = 20,
+		TYPE_ARGRAW = 21,
+		TYPE_INFO = 22,
+		TYPE_BUFFER = 23,
+		TYPE_RESSTR = 24,
+		TYPE_RESRAW = 25,
+		TYPE_FAILED = 26,
+		TYPE_ISIO = 27,
+		TYPE_ISIO_READ = 28,
+		TYPE_ISIO_WRITE = 29,
+		TYPE_IODIR = 30,
+		TYPE_ISWAIT = 31,
+		TYPE_ISSYSLOG = 32,
+		TYPE_COUNT = 33,
+		TYPE_AROUND = 34,
 	};
 
 	sinsp_filter_check_event();
